@@ -6,7 +6,7 @@ use warnings;
 use DynaLoader ();
 
 use vars qw( $VERSION @ISA @EXPORT @EXPORT_OK );
-$VERSION   = "0.40";
+$VERSION   = "0.45";
 @ISA       = qw( DynaLoader Exporter );
 @EXPORT    = qw( DDumper DTidy DDsort DPeek DDisplay DDump DHexDump
 		 DDual DGrow );
@@ -124,6 +124,8 @@ sub DTidy
 	"--no-check-syntax",
 	"--no-standard-output",
 	"--no-warning-output",
+	# RT#99514 - Perl::Tidy memoizes .perltidyrc incorrectly
+	"--no-memoize",
 	]);
     $s = $t;
 
@@ -394,6 +396,8 @@ Example
 
   "abc\nde\x{20ac}fg"
 
+In void context, C<DDisplay ()> uses C<warn> to display the result.
+
 =head2 DHexDump
 
 =head2 DHexDump ($var)
@@ -685,7 +689,7 @@ H.Merijn Brand <h.m.brand@xs4all.nl>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008-2014 H.Merijn Brand
+Copyright (C) 2008-2016 H.Merijn Brand
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
